@@ -1,8 +1,8 @@
 import os
 import logging
 from pds_github_util.tags.tags import Tags
+from pds_github_util.utils import RstClothReferenceable
 from pds_github_util.corral.herd import Herd
-from rstcloth import RstCloth
 from uuid import uuid4
 
 logging.basicConfig(level=logging.INFO)
@@ -10,82 +10,13 @@ logger = logging.getLogger(__name__)
 
 COLUMNS = ['manual', 'changelog', 'requirements', 'download', 'license', 'feedback']
 
-def _indent(content, indent):
-    """
-    :param content:
-    :param indent:
-    :return:
-    """
-    if indent == 0:
-        return content
-    else:
-        indent = " " * indent
-        if isinstance(content, list):
-            return ["".join([indent, line]) for line in content]
-        else:
-            return "".join([indent, content])
-
-
-class RstClothReferenceable(RstCloth):
-    def __init__(self, line_width=72):
-        super().__init__(line_width=line_width)
-        self._deffered_directives = []
-
-    def hyperlink(self, ref, url):
-        self._deffered_directives.append(f".. _{ref}: {url}")
-
-    def deffered_directive(self, name, arg=None, fields=None, content=None, indent=0, wrap=True, reference=None):
-        """
-        :param name: the directive itself to use
-        :param arg: the argument to pass into the directive
-        :param fields: fields to append as children underneath the directive
-        :param content: the text to write into this element
-        :param indent: (optional default=0) number of characters to indent this element
-        :param wrap: (optional, default=True) Whether or not to wrap lines to the line_width
-        :param reference: (optional, default=None) Reference to call the directive elswhere
-        :return:
-        """
-        logger.debug("Ignoring wrap parameter, presumably for api consistency. wrap=%s", wrap)
-        o = list()
-        if reference:
-            o.append(".. |{0}| {1}::".format(reference, name))
-        else:
-            o.append(".. {0}::".format(name))
-
-        if arg is not None:
-            o[0] += " " + arg
-
-        if fields is not None:
-            for k, v in fields:
-                o.append(_indent(":" + k + ": " + str(v), 3))
-
-        if content is not None:
-            o.append("")
-
-            if isinstance(content, list):
-                o.extend(_indent(content, 3))
-            else:
-                o.append(_indent(content, 3))
-
-        self._deffered_directives.extend(_indent(o, indent))
-
-    def write(self, filename):
-        """
-            :param filename:
-            :return:
-            """
-        dirpath = os.path.dirname(filename)
-        if os.path.isdir(dirpath) is False:
-          try:
-              os.makedirs(dirpath)
-          except OSError:
-              logger.info("{0} exists. ignoring.".format(dirpath))
-
-        with open(filename, "w") as f:
-          f.write("\n".join(self._data))
-          f.write("\n")
-          f.write("\n".join(self._deffered_directives))
-          f.write("\n")
+REPO_TYPES = {
+    'tool': 'PDS Tools',
+    'service': 'Discipline Node Services',
+    'library': 'Libraries',
+    'core': 'Other Core Services and Libraries',
+    'unknown': 'Unclassified software assets'
+}
 
 
 def get_table_columns_md():
@@ -138,20 +69,39 @@ def write_md_file(herd, output_file_name, version):
     software_summary_md.create_md_file()
 
 
+def write_rst_introduction(d: RstClothReferenceable, version: str):
+    d.title(f'Software Summary (build {version})')
+
+    d.content(f'The software provided for the build {version} are listed hereafter and organized by category:')
+    d.newline()
+    for t, section in REPO_TYPES.items():
+        if t != 'unknown':
+            d.li(f'`{section}`_')
+            d.newline()
+
 def write_rst_file(herd, output_file_name, version):
 
     d = RstClothReferenceable()
-    d.title(f'Software Summary (build {version})')
 
-    data = []
+    write_rst_introduction(d, version)
+
+    # create one section per type of repo
+    data = {t: [] for t in REPO_TYPES}
     for k, ch in herd.get_cattle_heads().items():
         ch.set_rst(d)
-        data.append(ch.get_table_row(format='rst'))
+        if ch.type in REPO_TYPES.keys():
+            data[ch.type].append(ch.get_table_row(format='rst'))
+        else:
+            logger.warning("unknown type for repo %s in build version %s", ch.repo_name, version)
+            data['unknown'].append(ch.get_table_row(format='rst'))
 
-    d.table(
-        get_table_columns_rst(),
-        data=data
-    )
+    for type, type_data in data.items():
+        if type_data:
+            d.h1(REPO_TYPES[type])
+            d.table(
+                get_table_columns_rst(),
+                data=type_data
+            )
 
     rst_column_header_images(d)
 
